#!/bin/bash

# Author: Victor Correal (victor.correal@bsc.es)
# Date  : 1/05/2024

source ../../bash_utils/helpers.sh

usage() {
    echo "Deployment script, use to deploy the model."
    echo "Usage: $0 "
    echo -e "\t--from-repo <repo> | --from-tar <path>"
    echo -e "\t--workdir --env <env>"
    echo "OPTIONAL FLAGS:"
    echo -e "\t[--force]"
    echo -e "\t[--git-branch]"   
}

parse_args() {
    OPTIONS=$(getopt -o "" --long from-repo:,from-tar:,force,workdir:,env:,git-branch:,help -n "$0" -- "$@")
    eval set -- "$OPTIONS"

    while true; do
        case "$1" in
            --from-repo)
                SOURCE_REPO="$2"
                shift 2
            ;;
            --from-tar)
                SOURCE_TAR="$2"
                echo 
                shift 2
            ;;
            --workdir)
                WORKDIR="$2"
                shift 2
            ;;
            --force)
                FORCE=true
                shift
            ;;
            --env)
                ENV_FILE="$2"
                shift 2
            ;;
            --git-branch)
                GIT_BRANCH="$2"
                GIT_BRANCH_CMD="-b $2"
                shift
            ;;
            --help)
                usage
                exit 0
            ;;
            --)
                shift
                break
            ;;
            *)
                usage
                exit 1
            ;;
        esac
    done
}

print_options() {
    info "=============================INSTALLATION==========================================="
    info "WORKDIR: $WORKDIR"
    [[ -z $SOURCE_REPO ]] || info "REPO: $SOURCE_REPO"
    [[ -z $GIT_BRANCH ]] || info "BRANCH: $GIT_BRANCH"
    [[ -z $SOURCE_TAR ]] || info "FILE: $SOURCE_TAR"
    [[ -z $ENV_FILE ]] || info "ENV: $ENV_FILE"
    info "===================================================================================="

    if [ $FORCE = false ]; then
        echo -n "¿FINE? (Y/N)"
        read ANSWER
        case "$ANSWER" in
            [Yy])
                echo ""
                ;;
            [Nn])
                echo "ABORT..."
                exit 0
                ;;
            *)
                echo "ABORT"
                exit 1
                ;;
        esac
    else
        info "Force ENABLED, skip ask to the user"
    fi
}

check_required_args() {
    [ -z $ENV_FILE ] && fatal "Select env file with --env"
    source $ENV_FILE
    [ -z $SOURCE_REPO ] && [ -z $SOURCE_TAR ] && fatal "Either --from-repo or --from-tar is required."
    [ -z $WORKDIR ] && fatal "Select the working directory with --workdir."
    [ -z $GIT_BRANCH ] && info "Using the default branch of the repo, you can tune this using --git-branch"
}

check_dir(){
    [ -d $WORKDIR ] && fatal "WORKDIR ALREADY EXIST. REMOVE IT OR USE ANOTHER."
    [ -d $WORKDIR ] || mkdir -p $WORKDIR
}

